@@ -14,6 +14,7 @@ from ioc.requirement import NO_DEFAULT
 from ioc.exc import UnsatisfiedDependency
 from ioc.exc import MissingDependencies
 from ioc.pkg import setup
+from ioc.pkg import teardown
 from ioc.provider import get_unsatisfied_dependencies
 
 
@@ -52,11 +53,6 @@ def override(name, value):
     return provide(name, value, force=True)
 
 
-def teardown():
-    """Tear down the configured dependencies."""
-    provider.teardown()
-
-
 def load(dependencies, override=False):
     s = schema.Parser(override=override).load(dependencies)
     s.resolve(schema.Resolver())
