@@ -1,6 +1,8 @@
 """Setup inversion-of-control through entrypoints."""
 import pkg_resources
 
+from . import provider
+
 
 IOC_ENTRYPOINT_NAME = 'ioc.providers'
 
@@ -32,3 +34,10 @@ def setup():
         module.setup_ioc()
 
     IS_CONFIGURED = True
+
+
+def teardown():
+    """Tear down the configured dependencies."""
+    global IS_CONFIGURED
+    provider.teardown()
+    IS_CONFIGURED = False
